@@ -1,13 +1,12 @@
 from warnings import warn
 
-from shapely.geometry import MultiPoint, MultiLineString, MultiPolygon
-from shapely.geometry.base import BaseGeometry
-from shapely.ops import cascaded_union, unary_union
-import shapely.affinity as affinity
-
 import numpy as np
 import pandas as pd
 from pandas import Series, DataFrame, MultiIndex
+from pandas.core.indexing import _NDFrameIndexer
+from shapely.geometry import box, MultiPoint, MultiLineString, MultiPolygon
+from shapely.ops import cascaded_union, unary_union
+import shapely.affinity as affinity
 
 import geopandas as gpd
 
@@ -54,11 +53,13 @@ def _series_op(this, other, op, **kwargs):
         return Series([getattr(s, op)(other, **kwargs) if s else null_val
                       for s in this.geometry], index=this.index)
 
+
 def _geo_unary_op(this, op):
     """Unary operation that returns a GeoSeries"""
     return gpd.GeoSeries([getattr(geom, op) for geom in this.geometry],
                      index=this.index, crs=this.crs)
 
+
 def _series_unary_op(this, op, null_value=False):
     """Unary operation that returns a Series"""
     return Series([getattr(geom, op, null_value) for geom in this.geometry],
@@ -66,9 +67,10 @@ def _series_unary_op(this, op, null_value=False):
 
 
 class GeoPandasBase(object):
+    _sindex = None
+    _sindex_generated = False
 
     def _generate_sindex(self):
-        self._sindex = None
         if not HAS_SINDEX:
             warn("Cannot generate spatial index: Missing package `rtree`.")
         else:
@@ -83,6 +85,7 @@ class GeoPandasBase(object):
             # and move on. See https://github.com/Toblerity/rtree/issues/20.
             except RTreeError:
                 pass
+        self._sindex_generated = True
 
     def _invalidate_sindex(self):
         """
@@ -91,7 +94,7 @@ class GeoPandasBase(object):
 
         """
         self._sindex = None
-        self._sindex_valid = False
+        self._sindex_generated = False
 
     @property
     def area(self):
@@ -184,7 +187,7 @@ class GeoPandasBase(object):
     @property
     def cascaded_union(self):
         """Deprecated: Return the unary_union of all geometries"""
-        return cascaded_union(self.values)
+        return cascaded_union(self.geometry.values)
 
     @property
     def unary_union(self):
@@ -281,16 +284,15 @@ class GeoPandasBase(object):
         """
 
         b = self.bounds
-        return (b['minx'].min(),
-                b['miny'].min(),
-                b['maxx'].max(),
-                b['maxy'].max())
+        return np.array((b['minx'].min(),
+                         b['miny'].min(),
+                         b['maxx'].max(),
+                         b['maxy'].max()))
 
     @property
     def sindex(self):
-        if not self._sindex_valid:
+        if not self._sindex_generated:
             self._generate_sindex()
-            self._sindex_valid = True
         return self._sindex
 
     def buffer(self, distance, resolution=16):
@@ -474,6 +476,37 @@ class GeoPandasBase(object):
         return gpd.GeoSeries(geometries,
             index=MultiIndex.from_tuples(index)).__finalize__(self)
 
+
+class _CoordinateIndexer(_NDFrameIndexer):
+    """
+    Coordinate based indexer to select by intersection with bounding box.
+
+    Format of input should be ``.cx[xmin:xmax, ymin:ymax]``. Any of ``xmin``,
+    ``xmax``, ``ymin``, and ``ymax`` can be provided, but input must
+    include a comma separating x and y slices. That is, ``.cx[:, :]`` will
+    return the full series/frame, but ``.cx[:]`` is not implemented.
+    """
+
+    def _getitem_tuple(self, tup):
+        obj = self.obj
+        xs, ys = tup
+        # handle numeric values as x and/or y coordinate index
+        if type(xs) is not slice:
+            xs = slice(xs, xs)
+        if type(ys) is not slice:
+            ys = slice(ys, ys)
+        # don't know how to handle step; should this raise?
+        if xs.step is not None or ys.step is not None:
+            warn("Ignoring step - full interval is used.")
+        xmin, ymin, xmax, ymax = obj.total_bounds
+        bbox = box(xs.start if xs.start is not None else xmin,
+                   ys.start if ys.start is not None else ymin,
+                   xs.stop if xs.stop is not None else xmax,
+                   ys.stop if ys.stop is not None else ymax)
+        idx = obj.intersects(bbox)
+        return obj[idx]
+
+
 def _array_input(arr):
     if isinstance(arr, (MultiPoint, MultiLineString, MultiPolygon)):
         # Prevent against improper length detection when input is a
