@@ -1,21 +1,16 @@
 from functools import partial
 import json
-from warnings import warn
 
 import numpy as np
-from pandas import Series, DataFrame
-from pandas.core.indexing import _NDFrameIndexer
-from pandas.util.decorators import cache_readonly
+from pandas import Series
 import pyproj
-from shapely.geometry import box, shape, Polygon, Point
-from shapely.geometry.collection import GeometryCollection
+from shapely.geometry import shape, Point
 from shapely.geometry.base import BaseGeometry
 from shapely.ops import transform
 
 from geopandas.plotting import plot_series
-from geopandas.base import GeoPandasBase
+from geopandas.base import GeoPandasBase, _series_unary_op, _CoordinateIndexer
 
-OLD_PANDAS = issubclass(Series, np.ndarray)
 
 def _is_empty(x):
     try:
@@ -23,32 +18,6 @@ def _is_empty(x):
     except:
         return False
 
-def _convert_array_args(args):
-    if len(args) == 1 and isinstance(args[0], BaseGeometry):
-        args = ([args[0]],)
-    return args
-
-class _CoordinateIndexer(_NDFrameIndexer):
-    """ Indexing by coordinate slices """
-    def _getitem_tuple(self, tup):
-        obj = self.obj
-        xs, ys = tup
-        # handle numeric values as x and/or y coordinate index
-        if type(xs) is not slice:
-            xs = slice(xs, xs)
-        if type(ys) is not slice:
-            ys = slice(ys, ys)
-        # don't know how to handle step; should this raise?
-        if xs.step is not None or ys.step is not None:
-            warn("Ignoring step - full interval is used.")
-        xmin, ymin, xmax, ymax = obj.total_bounds
-        bbox = box(xs.start or xmin,
-                   ys.start or ymin,
-                   xs.stop or xmax,
-                   ys.stop or ymax)
-        idx = obj.intersects(bbox)
-        return obj[idx]
-
 
 class GeoSeries(GeoPandasBase, Series):
     """A Series object designed to store shapely geometry objects."""
@@ -56,19 +25,17 @@ class GeoSeries(GeoPandasBase, Series):
 
     def __new__(cls, *args, **kwargs):
         kwargs.pop('crs', None)
-        if OLD_PANDAS:
-            args = _convert_array_args(args)
-            arr = Series.__new__(cls, *args, **kwargs)
-        else:
-            arr = Series.__new__(cls)
+        arr = Series.__new__(cls)
         if type(arr) is GeoSeries:
             return arr
         else:
             return arr.view(GeoSeries)
 
     def __init__(self, *args, **kwargs):
-        if not OLD_PANDAS:
-            args = _convert_array_args(args)
+        # fix problem for scalar geometries passed
+        if len(args) == 1 and isinstance(args[0], BaseGeometry):
+            args = ([args[0]],)
+
         crs = kwargs.pop('crs', None)
 
         super(GeoSeries, self).__init__(*args, **kwargs)
@@ -82,24 +49,42 @@ class GeoSeries(GeoPandasBase, Series):
     def geometry(self):
         return self
 
+    @property
+    def x(self):
+        """Return the x location of point geometries in a GeoSeries"""
+        if (self.geom_type == "Point").all():
+            return _series_unary_op(self, 'x', null_value=np.nan)
+        else:
+            message = "x attribute access only provided for Point geometries"
+            raise ValueError(message)
+
+    @property
+    def y(self):
+        """Return the y location of point geometries in a GeoSeries"""
+        if (self.geom_type == "Point").all():
+            return _series_unary_op(self, 'y', null_value=np.nan)
+        else:
+            message = "y attribute access only provided for Point geometries"
+            raise ValueError(message)
+
     @classmethod
     def from_file(cls, filename, **kwargs):
         """
         Alternate constructor to create a GeoSeries from a file
-        
+
         Parameters
         ----------
-        
+
         filename : str
             File path or file handle to read from. Depending on which kwargs
             are included, the content of filename may vary, see:
             http://toblerity.github.io/fiona/README.html#usage
             for usage details.
         kwargs : key-word arguments
-            These arguments are passed to fiona.open, and can be used to 
+            These arguments are passed to fiona.open, and can be used to
             access multi-layer data, data stored within archives (zip files),
             etc.
-        
+
         """
         import fiona
         geoms = []
@@ -125,7 +110,7 @@ class GeoSeries(GeoPandasBase, Series):
                           index=self.index)
         data.crs = self.crs
         data.to_file(filename, driver, **kwargs)
-        
+
     #
     # Implement pandas methods
     #
@@ -183,12 +168,50 @@ class GeoSeries(GeoPandasBase, Series):
         return GeoSeries(self.values.copy(order), index=self.index,
                       name=self.name).__finalize__(self)
 
-    def isnull(self):
-        """Null values in a GeoSeries are represented by empty geometric objects"""
+    def isna(self):
+        """
+        N/A values in a GeoSeries can be represented by empty geometric
+        objects, in addition to standard representations such as None and
+        np.nan.
+
+        Returns
+        -------
+        A boolean pandas Series of the same size as the GeoSeries,
+        True where a value is N/A.
+
+        See Also
+        --------
+        GeoSereies.notna : inverse of isna
+        """
         non_geo_null = super(GeoSeries, self).isnull()
         val = self.apply(_is_empty)
         return np.logical_or(non_geo_null, val)
 
+    def isnull(self):
+        """Alias for `isna` method. See `isna` for more detail."""
+        return self.isna()
+
+    def notna(self):
+        """
+        N/A values in a GeoSeries can be represented by empty geometric
+        objects, in addition to standard representations such as None and
+        np.nan.
+
+        Returns
+        -------
+        A boolean pandas Series of the same size as the GeoSeries,
+        False where a value is N/A.
+
+        See Also
+        --------
+        GeoSeries.isna : inverse of notna
+        """
+        return ~self.isna()
+
+    def notnull(self):
+        """Alias for `notna` method. See `notna` for more detail."""
+        return self.notna()
+
     def fillna(self, value=None, method=None, inplace=False,
                **kwargs):
         """Fill NA/NaN values with a geometry (empty polygon by default).
@@ -196,27 +219,14 @@ class GeoSeries(GeoPandasBase, Series):
         "method" is currently not implemented for pandas <= 0.12.
         """
         if value is None:
-            value = Point()
-        if not OLD_PANDAS:
-            return super(GeoSeries, self).fillna(value=value, method=method,
-                                                 inplace=inplace, **kwargs)
-        else:
-            # FIXME: this is an ugly way to support pandas <= 0.12
-            if method is not None:
-                raise NotImplementedError('Fill method is currently not implemented for GeoSeries')
-            if isinstance(value, BaseGeometry):
-                result = self.copy() if not inplace else self
-                mask = self.isnull()
-                result[mask] = value
-                if not inplace:
-                    return GeoSeries(result)
-            else:
-                raise ValueError('Non-geometric fill values not allowed for GeoSeries')
+            value = BaseGeometry()
+        return super(GeoSeries, self).fillna(value=value, method=method,
+                                             inplace=inplace, **kwargs)
 
     def align(self, other, join='outer', level=None, copy=True,
               fill_value=None, **kwargs):
         if fill_value is None:
-            fill_value = Point()
+            fill_value = BaseGeometry()
         left, right = super(GeoSeries, self).align(other, join=join,
                                                    level=level, copy=copy,
                                                    fill_value=fill_value,
@@ -241,7 +251,7 @@ class GeoSeries(GeoPandasBase, Series):
 
     def plot(self, *args, **kwargs):
         return plot_series(self, *args, **kwargs)
-    
+
     plot.__doc__ = plot_series.__doc__
 
     #
