@@ -7,40 +7,43 @@ import shutil
 
 import numpy as np
 import pandas as pd
-from pandas.util.testing import assert_frame_equal
 from shapely.geometry import Point, Polygon
-
 import fiona
+
+import geopandas
 from geopandas import GeoDataFrame, read_file, GeoSeries
-from geopandas.tests.util import assert_geoseries_equal, connect, create_db, \
-    download_nybb, PACKAGE_DIR, PANDAS_NEW_SQL_API, unittest, validate_boro_df
+
+from geopandas.tests.util import (
+    assert_geoseries_equal, connect, create_db, PACKAGE_DIR,
+    validate_boro_df)
+from pandas.util.testing import assert_frame_equal
+import pytest
 
 
-class TestDataFrame(unittest.TestCase):
+class TestDataFrame:
 
-    def setUp(self):
+    def setup_method(self):
         N = 10
 
-        nybb_filename, nybb_zip_path = download_nybb()
+        nybb_filename = geopandas.datasets.get_path('nybb')
 
-        self.df = read_file(nybb_zip_path, vfs='zip://' + nybb_filename)
-        with fiona.open(nybb_zip_path, vfs='zip://' + nybb_filename) as f:
-            self.schema = f.schema
+        self.df = read_file(nybb_filename)
         self.tempdir = tempfile.mkdtemp()
         self.boros = self.df['BoroName']
         self.crs = {'init': 'epsg:4326'}
         self.df2 = GeoDataFrame([
             {'geometry': Point(x, y), 'value1': x + y, 'value2': x * y}
             for x, y in zip(range(N), range(N))], crs=self.crs)
-        self.df3 = read_file(os.path.join(PACKAGE_DIR, 'examples', 'null_geom.geojson'))
+        self.df3 = read_file(
+            os.path.join(PACKAGE_DIR, 'examples', 'null_geom.geojson'))
         self.line_paths = self.df3['Name']
 
-    def tearDown(self):
+    def teardown_method(self):
         shutil.rmtree(self.tempdir)
 
     def test_df_init(self):
-        self.assertTrue(type(self.df2) is GeoDataFrame)
-        self.assertTrue(self.df2.crs == self.crs)
+        assert type(self.df2) is GeoDataFrame
+        assert self.df2.crs == self.crs
 
     def test_different_geo_colname(self):
         data = {"A": range(5), "B": range(-5, 0),
@@ -48,16 +51,16 @@ class TestDataFrame(unittest.TestCase):
         df = GeoDataFrame(data, crs=self.crs, geometry='location')
         locs = GeoSeries(data['location'], crs=self.crs)
         assert_geoseries_equal(df.geometry, locs)
-        self.assert_('geometry' not in df)
-        self.assertEqual(df.geometry.name, 'location')
+        assert 'geometry' not in df
+        assert df.geometry.name == 'location'
         # internal implementation detail
-        self.assertEqual(df._geometry_column_name, 'location')
+        assert df._geometry_column_name == 'location'
 
         geom2 = [Point(x, y) for x, y in zip(range(5, 10), range(5))]
         df2 = df.set_geometry(geom2, crs='dummy_crs')
-        self.assert_('location' in df2)
-        self.assertEqual(df2.crs, 'dummy_crs')
-        self.assertEqual(df2.geometry.crs, 'dummy_crs')
+        assert 'location' in df2
+        assert df2.crs == 'dummy_crs'
+        assert df2.geometry.crs == 'dummy_crs'
         # reset so it outputs okay
         df2.crs = df.crs
         assert_geoseries_equal(df2.geometry, GeoSeries(geom2, crs=df2.crs))
@@ -66,28 +69,29 @@ class TestDataFrame(unittest.TestCase):
         data = {"A": range(5), "B": range(-5, 0),
                 "location": [Point(x, y) for x, y in zip(range(5), range(5))]}
         df = GeoDataFrame(data, crs=self.crs, geometry='location')
-        self.assert_(isinstance(df.geometry, GeoSeries))
+        assert isinstance(df.geometry, GeoSeries)
         df['geometry'] = df["A"]
-        self.assert_(isinstance(df.geometry, GeoSeries))
-        self.assertEqual(df.geometry[0], data['location'][0])
+        assert isinstance(df.geometry, GeoSeries)
+        assert df.geometry[0] == data['location'][0]
         # good if this changed in the future
-        self.assert_(not isinstance(df['geometry'], GeoSeries))
-        self.assert_(isinstance(df['location'], GeoSeries))
+        assert not isinstance(df['geometry'], GeoSeries)
+        assert isinstance(df['location'], GeoSeries)
 
-        data["geometry"] = [Point(x + 1, y - 1) for x, y in zip(range(5), range(5))]
+        data["geometry"] = [Point(x + 1, y - 1) for x, y in zip(range(5),
+                                                                range(5))]
         df = GeoDataFrame(data, crs=self.crs)
-        self.assert_(isinstance(df.geometry, GeoSeries))
-        self.assert_(isinstance(df['geometry'], GeoSeries))
+        assert isinstance(df.geometry, GeoSeries)
+        assert isinstance(df['geometry'], GeoSeries)
         # good if this changed in the future
-        self.assert_(not isinstance(df['location'], GeoSeries))
+        assert not isinstance(df['location'], GeoSeries)
 
     def test_geometry_property(self):
         assert_geoseries_equal(self.df.geometry, self.df['geometry'],
-                                  check_dtype=True, check_index_type=True)
+                               check_dtype=True, check_index_type=True)
 
         df = self.df.copy()
         new_geom = [Point(x, y) for x, y in zip(range(len(self.df)),
-                                               range(len(self.df)))]
+                                                range(len(self.df)))]
         df.geometry = new_geom
 
         new_geom = GeoSeries(new_geom, index=df.index, crs=df.crs)
@@ -97,36 +101,36 @@ class TestDataFrame(unittest.TestCase):
         # new crs
         gs = GeoSeries(new_geom, crs="epsg:26018")
         df.geometry = gs
-        self.assertEqual(df.crs, "epsg:26018")
+        assert df.crs == "epsg:26018"
 
     def test_geometry_property_errors(self):
-        with self.assertRaises(AttributeError):
+        with pytest.raises(AttributeError):
             df = self.df.copy()
             del df['geometry']
             df.geometry
 
         # list-like error
-        with self.assertRaises(ValueError):
+        with pytest.raises(ValueError):
             df = self.df2.copy()
             df.geometry = 'value1'
 
         # list-like error
-        with self.assertRaises(ValueError):
+        with pytest.raises(ValueError):
             df = self.df.copy()
             df.geometry = 'apple'
 
         # non-geometry error
-        with self.assertRaises(TypeError):
+        with pytest.raises(TypeError):
             df = self.df.copy()
             df.geometry = list(range(df.shape[0]))
 
-        with self.assertRaises(KeyError):
+        with pytest.raises(KeyError):
             df = self.df.copy()
             del df['geometry']
             df['geometry']
 
         # ndim error
-        with self.assertRaises(ValueError):
+        with pytest.raises(ValueError):
             df = self.df.copy()
             df.geometry = df
 
@@ -135,32 +139,32 @@ class TestDataFrame(unittest.TestCase):
         original_geom = self.df.geometry
 
         df2 = self.df.set_geometry(geom)
-        self.assert_(self.df is not df2)
+        assert self.df is not df2
         assert_geoseries_equal(df2.geometry, geom)
         assert_geoseries_equal(self.df.geometry, original_geom)
         assert_geoseries_equal(self.df['geometry'], self.df.geometry)
         # unknown column
-        with self.assertRaises(ValueError):
+        with pytest.raises(ValueError):
             self.df.set_geometry('nonexistent-column')
 
         # ndim error
-        with self.assertRaises(ValueError):
+        with pytest.raises(ValueError):
             self.df.set_geometry(self.df)
 
         # new crs - setting should default to GeoSeries' crs
         gs = GeoSeries(geom, crs="epsg:26018")
         new_df = self.df.set_geometry(gs)
-        self.assertEqual(new_df.crs, "epsg:26018")
+        assert new_df.crs == "epsg:26018"
 
         # explicit crs overrides self and dataframe
         new_df = self.df.set_geometry(gs, crs="epsg:27159")
-        self.assertEqual(new_df.crs, "epsg:27159")
-        self.assertEqual(new_df.geometry.crs, "epsg:27159")
+        assert new_df.crs == "epsg:27159"
+        assert new_df.geometry.crs == "epsg:27159"
 
         # Series should use dataframe's
         new_df = self.df.set_geometry(geom.values)
-        self.assertEqual(new_df.crs, self.df.crs)
-        self.assertEqual(new_df.geometry.crs, self.df.crs)
+        assert new_df.crs == self.df.crs
+        assert new_df.geometry.crs == self.df.crs
 
     def test_set_geometry_col(self):
         g = self.df.geometry
@@ -169,18 +173,18 @@ class TestDataFrame(unittest.TestCase):
         df2 = self.df.set_geometry('simplified_geometry')
 
         # Drop is false by default
-        self.assert_('simplified_geometry' in df2)
+        assert 'simplified_geometry' in df2
         assert_geoseries_equal(df2.geometry, g_simplified)
 
         # If True, drops column and renames to geometry
         df3 = self.df.set_geometry('simplified_geometry', drop=True)
-        self.assert_('simplified_geometry' not in df3)
+        assert 'simplified_geometry' not in df3
         assert_geoseries_equal(df3.geometry, g_simplified)
 
     def test_set_geometry_inplace(self):
         geom = [Point(x, y) for x, y in zip(range(5), range(5))]
         ret = self.df.set_geometry(geom, inplace=True)
-        self.assert_(ret is None)
+        assert ret is None
         geom = GeoSeries(geom, index=self.df.index, crs=self.df.crs)
         assert_geoseries_equal(self.df.geometry, geom)
 
@@ -202,14 +206,14 @@ class TestDataFrame(unittest.TestCase):
         df = self.df.set_geometry(g)
 
         for i, r in df.iterrows():
-            self.assertAlmostEqual(i, r['geometry'].x)
-            self.assertAlmostEqual(i, r['geometry'].y)
+            assert i == r['geometry'].x
+            assert i == r['geometry'].y
 
     def test_to_json(self):
         text = self.df.to_json()
         data = json.loads(text)
-        self.assertTrue(data['type'] == 'FeatureCollection')
-        self.assertTrue(len(data['features']) == 5)
+        assert data['type'] == 'FeatureCollection'
+        assert len(data['features']) == 5
 
     def test_to_json_geom_col(self):
         df = self.df.copy()
@@ -219,72 +223,72 @@ class TestDataFrame(unittest.TestCase):
 
         text = df.to_json()
         data = json.loads(text)
-        self.assertTrue(data['type'] == 'FeatureCollection')
-        self.assertTrue(len(data['features']) == 5)
+        assert data['type'] == 'FeatureCollection'
+        assert len(data['features']) == 5
 
     def test_to_json_na(self):
         # Set a value as nan and make sure it's written
-        self.df.loc[self.df['BoroName']=='Queens', 'Shape_Area'] = np.nan
+        self.df.loc[self.df['BoroName'] == 'Queens', 'Shape_Area'] = np.nan
 
         text = self.df.to_json()
         data = json.loads(text)
-        self.assertTrue(len(data['features']) == 5)
+        assert len(data['features']) == 5
         for f in data['features']:
             props = f['properties']
-            self.assertEqual(len(props), 4)
+            assert len(props) == 4
             if props['BoroName'] == 'Queens':
-                self.assertTrue(props['Shape_Area'] is None)
+                assert props['Shape_Area'] is None
 
     def test_to_json_bad_na(self):
         # Check that a bad na argument raises error
-        with self.assertRaises(ValueError):
-            text = self.df.to_json(na='garbage')
+        with pytest.raises(ValueError):
+            self.df.to_json(na='garbage')
 
     def test_to_json_dropna(self):
-        self.df.loc[self.df['BoroName']=='Queens', 'Shape_Area'] = np.nan
-        self.df.loc[self.df['BoroName']=='Bronx', 'Shape_Leng'] = np.nan
+        self.df.loc[self.df['BoroName'] == 'Queens', 'Shape_Area'] = np.nan
+        self.df.loc[self.df['BoroName'] == 'Bronx', 'Shape_Leng'] = np.nan
 
         text = self.df.to_json(na='drop')
         data = json.loads(text)
-        self.assertEqual(len(data['features']), 5)
+        assert len(data['features']) == 5
         for f in data['features']:
             props = f['properties']
             if props['BoroName'] == 'Queens':
-                self.assertEqual(len(props), 3)
-                self.assertTrue('Shape_Area' not in props)
+                assert len(props) == 3
+                assert 'Shape_Area' not in props
                 # Just make sure setting it to nan in a different row
                 # doesn't affect this one
-                self.assertTrue('Shape_Leng' in props)
+                assert 'Shape_Leng' in props
             elif props['BoroName'] == 'Bronx':
-                self.assertEqual(len(props), 3)
-                self.assertTrue('Shape_Leng' not in props)
-                self.assertTrue('Shape_Area' in props)
+                assert len(props) == 3
+                assert 'Shape_Leng' not in props
+                assert 'Shape_Area' in props
             else:
-                self.assertEqual(len(props), 4)
+                assert len(props) == 4
 
     def test_to_json_keepna(self):
-        self.df.loc[self.df['BoroName']=='Queens', 'Shape_Area'] = np.nan
-        self.df.loc[self.df['BoroName']=='Bronx', 'Shape_Leng'] = np.nan
+        self.df.loc[self.df['BoroName'] == 'Queens', 'Shape_Area'] = np.nan
+        self.df.loc[self.df['BoroName'] == 'Bronx', 'Shape_Leng'] = np.nan
 
         text = self.df.to_json(na='keep')
         data = json.loads(text)
-        self.assertEqual(len(data['features']), 5)
+        assert len(data['features']) == 5
         for f in data['features']:
             props = f['properties']
-            self.assertEqual(len(props), 4)
+            assert len(props) == 4
             if props['BoroName'] == 'Queens':
-                self.assertTrue(np.isnan(props['Shape_Area']))
+                assert np.isnan(props['Shape_Area'])
                 # Just make sure setting it to nan in a different row
                 # doesn't affect this one
-                self.assertTrue('Shape_Leng' in props)
+                assert 'Shape_Leng' in props
             elif props['BoroName'] == 'Bronx':
-                self.assertTrue(np.isnan(props['Shape_Leng']))
-                self.assertTrue('Shape_Area' in props)
+                assert np.isnan(props['Shape_Leng'])
+                assert 'Shape_Area' in props
 
     def test_copy(self):
         df2 = self.df.copy()
-        self.assertTrue(type(df2) is GeoDataFrame)
-        self.assertEqual(self.df.crs, df2.crs)
+        assert type(df2) is GeoDataFrame
+        assert self.df.crs == df2.crs
 
     def test_to_file(self):
         """ Test to_file and from_file """
@@ -292,18 +296,18 @@ class TestDataFrame(unittest.TestCase):
         self.df.to_file(tempfilename)
         # Read layer back in
         df = GeoDataFrame.from_file(tempfilename)
-        self.assertTrue('geometry' in df)
-        self.assertTrue(len(df) == 5)
-        self.assertTrue(np.alltrue(df['BoroName'].values == self.boros))
+        assert 'geometry' in df
+        assert len(df) == 5
+        assert np.alltrue(df['BoroName'].values == self.boros)
 
         # Write layer with null geometry out to file
         tempfilename = os.path.join(self.tempdir, 'null_geom.shp')
         self.df3.to_file(tempfilename)
         # Read layer back in
         df3 = GeoDataFrame.from_file(tempfilename)
-        self.assertTrue('geometry' in df3)
-        self.assertTrue(len(df3) == 2)
-        self.assertTrue(np.alltrue(df3['Name'].values == self.line_paths))
+        assert 'geometry' in df3
+        assert len(df3) == 2
+        assert np.alltrue(df3['Name'].values == self.line_paths)
 
     def test_to_file_types(self):
         """ Test various integer type columns (GH#93) """
@@ -312,7 +316,7 @@ class TestDataFrame(unittest.TestCase):
                      np.uint8, np.uint16, np.uint32, np.uint64, np.long]
         geometry = self.df2.geometry
         data = dict((str(i), np.arange(len(geometry), dtype=dtype))
-                     for i, dtype in enumerate(int_types))
+                    for i, dtype in enumerate(int_types))
         df = GeoDataFrame(data, geometry=geometry)
         df.to_file(tempfilename)
 
@@ -320,20 +324,17 @@ class TestDataFrame(unittest.TestCase):
         """ Test that mixed geometry types raise error when writing to file """
         tempfilename = os.path.join(self.tempdir, 'test.shp')
         s = GeoDataFrame({'geometry': [Point(0, 0),
-                                        Polygon([(0, 0), (1, 0), (1, 1)])]})
-        with self.assertRaises(ValueError):
+                                       Polygon([(0, 0), (1, 0), (1, 1)])]})
+        with pytest.raises(ValueError):
             s.to_file(tempfilename)
 
     def test_to_file_schema(self):
         """
         Ensure that the file is written according to the schema
         if it is specified
-        
+
         """
-        try:
-            from collections import OrderedDict
-        except ImportError:
-            from ordereddict import OrderedDict
+        from collections import OrderedDict
 
         tempfilename = os.path.join(self.tempdir, 'test.shp')
         properties = OrderedDict([
@@ -350,23 +351,31 @@ class TestDataFrame(unittest.TestCase):
         with fiona.open(tempfilename) as f:
             result_schema = f.schema
 
-        self.assertEqual(result_schema, schema)
+        assert result_schema == schema
 
     def test_bool_index(self):
         # Find boros with 'B' in their name
         df = self.df[self.df['BoroName'].str.contains('B')]
-        self.assertTrue(len(df) == 2)
+        assert len(df) == 2
         boros = df['BoroName'].values
-        self.assertTrue('Brooklyn' in boros)
-        self.assertTrue('Bronx' in boros)
-        self.assertTrue(type(df) is GeoDataFrame)
+        assert 'Brooklyn' in boros
+        assert 'Bronx' in boros
+        assert type(df) is GeoDataFrame
+
+    def test_coord_slice_points(self):
+        assert self.df2.cx[-2:-1, -2:-1].empty
+        assert_frame_equal(self.df2, self.df2.cx[:, :])
+        assert_frame_equal(self.df2.loc[5:], self.df2.cx[5:, :])
+        assert_frame_equal(self.df2.loc[5:], self.df2.cx[:, 5:])
+        assert_frame_equal(self.df2.loc[5:], self.df2.cx[5:, 5:])
 
     def test_transform(self):
         df2 = self.df2.copy()
         df2.crs = {'init': 'epsg:26918', 'no_defs': True}
         lonlat = df2.to_crs(epsg=4326)
         utm = lonlat.to_crs(epsg=26918)
-        self.assertTrue(all(df2['geometry'].geom_almost_equals(utm['geometry'], decimal=2)))
+        assert all(df2['geometry'].geom_almost_equals(utm['geometry'],
+                                                      decimal=2))
 
     def test_to_crs_geo_column_name(self):
         # Test to_crs() with different geometry column name (GH#339)
@@ -376,37 +385,36 @@ class TestDataFrame(unittest.TestCase):
         df2.set_geometry('geom', inplace=True)
         lonlat = df2.to_crs(epsg=4326)
         utm = lonlat.to_crs(epsg=26918)
-        self.assertEqual(lonlat.geometry.name, 'geom')
-        self.assertEqual(utm.geometry.name, 'geom')
-        self.assertTrue(all(df2.geometry.geom_almost_equals(utm.geometry, decimal=2)))
+        assert lonlat.geometry.name == 'geom'
+        assert utm.geometry.name == 'geom'
+        assert all(df2.geometry.geom_almost_equals(utm.geometry, decimal=2))
 
     def test_from_features(self):
-        nybb_filename, nybb_zip_path = download_nybb()
-        with fiona.open(nybb_zip_path,
-                        vfs='zip://' + nybb_filename) as f:
+        nybb_filename = geopandas.datasets.get_path('nybb')
+        with fiona.open(nybb_filename) as f:
             features = list(f)
             crs = f.crs
 
         df = GeoDataFrame.from_features(features, crs=crs)
         df.rename(columns=lambda x: x.lower(), inplace=True)
-        validate_boro_df(self, df)
-        self.assert_(df.crs == crs)
+        validate_boro_df(df)
+        assert df.crs == crs
 
     def test_from_features_unaligned_properties(self):
         p1 = Point(1, 1)
         f1 = {'type': 'Feature',
-                'properties': {'a': 0},
-                'geometry': p1.__geo_interface__}
+              'properties': {'a': 0},
+              'geometry': p1.__geo_interface__}
 
         p2 = Point(2, 2)
         f2 = {'type': 'Feature',
-                'properties': {'b': 1},
-                'geometry': p2.__geo_interface__}
+              'properties': {'b': 1},
+              'geometry': p2.__geo_interface__}
 
         p3 = Point(3, 3)
         f3 = {'type': 'Feature',
-                'properties': {'a': 2},
-                'geometry': p3.__geo_interface__}
+              'properties': {'a': 2},
+              'geometry': p3.__geo_interface__}
 
         df = GeoDataFrame.from_features([f1, f2, f3])
 
@@ -416,26 +424,46 @@ class TestDataFrame(unittest.TestCase):
                                            {'a': 2, 'b': np.nan}])
         assert_frame_equal(expected, result)
 
+    def test_from_feature_collection(self):
+        data = {'name': ['a', 'b', 'c'],
+                'lat': [45, 46, 47.5],
+                'lon': [-120, -121.2, -122.9]}
+
+        df = pd.DataFrame(data)
+        geometry = [Point(xy) for xy in zip(df['lon'], df['lat'])]
+        gdf = GeoDataFrame(df, geometry=geometry)
+        # from_features returns sorted columns
+        expected = gdf[['geometry', 'lat', 'lon', 'name']]
+
+        # test FeatureCollection
+        res = GeoDataFrame.from_features(gdf.__geo_interface__)
+        assert_frame_equal(res, expected)
+
+        # test list of Features
+        res = GeoDataFrame.from_features(gdf.__geo_interface__['features'])
+        assert_frame_equal(res, expected)
+
+        # test __geo_interface__ attribute (a GeoDataFrame has one)
+        res = GeoDataFrame.from_features(gdf)
+        assert_frame_equal(res, expected)
+
     def test_from_postgis_default(self):
         con = connect('test_geopandas')
         if con is None or not create_db(self.df):
-            raise unittest.case.SkipTest()
+            raise pytest.skip()
 
         try:
             sql = "SELECT * FROM nybb;"
             df = GeoDataFrame.from_postgis(sql, con)
         finally:
-            if PANDAS_NEW_SQL_API:
-                # It's not really a connection, it's an engine
-                con = con.connect()
             con.close()
 
-        validate_boro_df(self, df)
+        validate_boro_df(df)
 
     def test_from_postgis_custom_geom_col(self):
         con = connect('test_geopandas')
         if con is None or not create_db(self.df):
-            raise unittest.case.SkipTest()
+            raise pytest.skip()
 
         try:
             sql = """SELECT
@@ -444,61 +472,57 @@ class TestDataFrame(unittest.TestCase):
                      FROM nybb;"""
             df = GeoDataFrame.from_postgis(sql, con, geom_col='__geometry__')
         finally:
-            if PANDAS_NEW_SQL_API:
-                # It's not really a connection, it's an engine
-                con = con.connect()
             con.close()
 
-        validate_boro_df(self, df)
+        validate_boro_df(df)
 
     def test_dataframe_to_geodataframe(self):
         df = pd.DataFrame({"A": range(len(self.df)), "location":
                            list(self.df.geometry)}, index=self.df.index)
         gf = df.set_geometry('location', crs=self.df.crs)
-        self.assertIsInstance(df, pd.DataFrame)
-        self.assertIsInstance(gf, GeoDataFrame)
+        assert isinstance(df, pd.DataFrame)
+        assert isinstance(gf, GeoDataFrame)
         assert_geoseries_equal(gf.geometry, self.df.geometry)
-        self.assertEqual(gf.geometry.name, 'location')
-        self.assert_('geometry' not in gf)
+        assert gf.geometry.name == 'location'
+        assert 'geometry' not in gf
 
         gf2 = df.set_geometry('location', crs=self.df.crs, drop=True)
-        self.assertIsInstance(df, pd.DataFrame)
-        self.assertIsInstance(gf2, GeoDataFrame)
-        self.assertEqual(gf2.geometry.name, 'geometry')
-        self.assert_('geometry' in gf2)
-        self.assert_('location' not in gf2)
-        self.assert_('location' in df)
+        assert isinstance(df, pd.DataFrame)
+        assert isinstance(gf2, GeoDataFrame)
+        assert gf2.geometry.name == 'geometry'
+        assert 'geometry' in gf2
+        assert 'location' not in gf2
+        assert 'location' in df
 
         # should be a copy
         df.ix[0, "A"] = 100
-        self.assertEqual(gf.ix[0, "A"], 0)
-        self.assertEqual(gf2.ix[0, "A"], 0)
+        assert gf.ix[0, "A"] == 0
+        assert gf2.ix[0, "A"] == 0
 
-        with self.assertRaises(ValueError):
+        with pytest.raises(ValueError):
             df.set_geometry('location', inplace=True)
 
     def test_geodataframe_geointerface(self):
-        self.assertEqual(self.df.__geo_interface__['type'], 'FeatureCollection')
-        self.assertEqual(len(self.df.__geo_interface__['features']),
-                         self.df.shape[0])
+        assert self.df.__geo_interface__['type'] == 'FeatureCollection'
+        assert len(self.df.__geo_interface__['features']) == self.df.shape[0]
 
     def test_geodataframe_geojson_no_bbox(self):
         geo = self.df._to_geo(na="null", show_bbox=False)
-        self.assertFalse('bbox' in geo.keys())
+        assert 'bbox' not in geo.keys()
         for feature in geo['features']:
-            self.assertFalse('bbox' in feature.keys())
+            assert 'bbox' not in feature.keys()
 
     def test_geodataframe_geojson_bbox(self):
         geo = self.df._to_geo(na="null", show_bbox=True)
-        self.assertTrue('bbox' in geo.keys())
-        self.assertEqual(len(geo['bbox']), 4)
-        self.assertTrue(isinstance(geo['bbox'], tuple))
+        assert 'bbox' in geo.keys()
+        assert len(geo['bbox']) == 4
+        assert isinstance(geo['bbox'], tuple)
         for feature in geo['features']:
-            self.assertTrue('bbox' in feature.keys())
+            assert 'bbox' in feature.keys()
 
     def test_pickle(self):
         filename = os.path.join(self.tempdir, 'df.pkl')
         self.df.to_pickle(filename)
         unpickled = pd.read_pickle(filename)
         assert_frame_equal(self.df, unpickled)
-        self.assertEqual(self.df.crs, unpickled.crs)
+        assert self.df.crs == unpickled.crs
